###############
Getting started
###############

.. contents:: Table of Contents
   :local:
   :backlinks: none


.. include:: _getting_started/analysis.rst
.. include:: _getting_started/model_building.rst
